@@ -5,11 +5,11 @@ use Pod::Markdown;
 use CPAN::Meta;
 use Pcore::API::PAUSE;
 
-has dist => ( is => 'ro', isa => InstanceOf ['Pcore::Dist'], required => 1 );
+has dist => ( required => 1 );    # InstanceOf ['Pcore::Dist']
 
-has major  => ( is => 'ro', isa => Bool, default => 0 );
-has minor  => ( is => 'ro', isa => Bool, default => 0 );
-has bugfix => ( is => 'ro', isa => Bool, default => 0 );
+has major  => 0;                  # Bool
+has minor  => 0;                  # Bool
+has bugfix => 0;                  # Bool
 
 sub run ($self) {
 
@@ -17,7 +17,7 @@ sub run ($self) {
     return if !$self->_can_release;
 
     # create new version
-    my $cur_ver = $self->dist->id->{release};
+    my $cur_ver = $self->{dist}->id->{release};
 
     my $new_ver = $self->_compose_new_version;
 
@@ -32,41 +32,41 @@ sub run ($self) {
     say q[];
 
     # run tests
-    return if !$self->dist->build->test( author => 1, release => 1 );
+    return if !$self->{dist}->build->test( author => 1, release => 1 );
 
     say q[];
 
     # NOTE !!!WARNING!!! start release, next changes will be hard to revert
 
     # update release version in the main module
-    unless ( $self->dist->module->content->$* =~ s[^(\s*package\s+\w[\w\:\']*\s+)v?[\d._]+(\s*;)][$1$new_ver$2]sm ) {
+    unless ( $self->{dist}->module->content->$* =~ s[^(\s*package\s+\w[\w\:\']*\s+)v?[\d._]+(\s*;)][$1$new_ver$2]sm ) {
         say q[Error updating version in the main dist module];
 
         return;
     }
 
-    P->file->write_bin( $self->dist->module->path, $self->dist->module->content );
+    P->file->write_bin( $self->{dist}->module->path, $self->{dist}->module->content );
 
     # clear cached data
-    $self->dist->clear;
+    $self->{dist}->clear;
 
     # update working copy
-    $self->dist->build->update;
+    $self->{dist}->build->update;
 
     # update CHANGES file
     # $self->_create_changes( $new_ver, $closed_issues->{data} );
     $self->_create_changes( $new_ver, undef );
 
     # generate wiki
-    if ( $self->dist->build->wiki ) {
-        $self->dist->build->wiki->run;
+    if ( $self->{dist}->build->wiki ) {
+        $self->{dist}->build->wiki->run;
     }
 
     # add/remove
     {
         print 'Add/remove changes ... ';
 
-        my $res = $self->dist->scm->scm_addremove;
+        my $res = $self->{dist}->scm->scm_addremove;
 
         say $res && return if !$res;
 
@@ -77,7 +77,7 @@ sub run ($self) {
     {
         print 'Committing ... ';
 
-        my $res = $self->dist->scm->scm_commit(qq[release $new_ver]);
+        my $res = $self->{dist}->scm->scm_commit(qq[release $new_ver]);
 
         say $res && return if !$res;
 
@@ -88,18 +88,18 @@ sub run ($self) {
     {
         print 'Setting tags ... ';
 
-        my $res = $self->dist->scm->scm_set_tag( [ 'latest', $new_ver ], 1 );
+        my $res = $self->{dist}->scm->scm_set_tag( [ 'latest', $new_ver ], 1 );
 
         say $res && return if !$res;
 
         say 'done';
     }
 
-    if ( $self->dist->scm->upstream ) {
+    if ( $self->{dist}->scm->upstream ) {
       PUSH_UPSTREAM:
         print 'Pushing to the upstream repository ... ';
 
-        my $res = $self->dist->scm->scm_push;
+        my $res = $self->{dist}->scm->scm_push;
 
         say $res->{reason};
 
@@ -108,74 +108,74 @@ sub run ($self) {
         }
     }
 
-    if ( $self->dist->docker ) {
+    if ( $self->{dist}->docker ) {
         require Pcore::API::DockerHub;
 
         my $dockerhub_api = Pcore::API::DockerHub->new;
 
       CREATE_DOCKERHUB_LATEST_TAG:
-        if ( !$self->dist->build->docker->create_tag( 'latest', 'latest', $Pcore::API::DockerHub::DOCKERHUB_SOURCE_TYPE_TAG, '/' ) ) {
+        if ( !$self->{dist}->build->docker->create_tag( 'latest', 'latest', $Pcore::API::DockerHub::DOCKERHUB_SOURCE_TYPE_TAG, '/' ) ) {
             goto CREATE_DOCKERHUB_LATEST_TAG if P->term->prompt( q[Repeat?], [qw[yes no]], enter => 1 ) eq 'yes';
         }
 
       CREATE_DOCKERHUB_VERSION_TAG:
-        if ( !$self->dist->build->docker->create_tag( $new_ver, $new_ver, $Pcore::API::DockerHub::DOCKERHUB_SOURCE_TYPE_TAG, '/' ) ) {
+        if ( !$self->{dist}->build->docker->create_tag( $new_ver, $new_ver, $Pcore::API::DockerHub::DOCKERHUB_SOURCE_TYPE_TAG, '/' ) ) {
             goto CREATE_DOCKERHUB_VERSION_TAG if P->term->prompt( q[Repeat?], [qw[yes no]], enter => 1 ) eq 'yes';
         }
 
       TRIGGER_BUILD_LATEST_TAG:
-        if ( !$self->dist->build->docker->trigger_build('latest') ) {
+        if ( !$self->{dist}->build->docker->trigger_build('latest') ) {
             goto TRIGGER_BUILD_LATEST_TAG if P->term->prompt( q[Repeat?], [qw[yes no]], enter => 1 ) eq 'yes';
         }
 
       TRIGGER_BUILD_VERSION_TAG:
-        if ( !$self->dist->build->docker->trigger_build($new_ver) ) {
+        if ( !$self->{dist}->build->docker->trigger_build($new_ver) ) {
             goto TRIGGER_BUILD_VERSION_TAG if P->term->prompt( q[Repeat?], [qw[yes no]], enter => 1 ) eq 'yes';
         }
     }
 
     # upload to the CPAN if this is the CPAN distribution, prompt before upload
-    $self->_upload_to_cpan if $self->dist->cfg->{cpan};
+    $self->_upload_to_cpan if $self->{dist}->cfg->{cpan};
 
     return 1;
 }
 
 sub _can_release ($self) {
-    if ( !$self->dist->scm ) {
+    if ( !$self->{dist}->scm ) {
         say q[SCM is required.];
 
         return;
     }
 
     # check for uncommited changes
-    if ( !$self->dist->is_commited ) {
+    if ( !$self->{dist}->is_commited ) {
         say q[Working copy or sub-repositories has uncommited changes or unknown files.];
 
         return;
     }
 
-    if ( $self->dist->cfg->{cpan} && !$ENV->user_cfg->{PAUSE}->{username} || !$ENV->user_cfg->{PAUSE}->{password} ) {
+    if ( $self->{dist}->cfg->{cpan} && !$ENV->user_cfg->{PAUSE}->{username} || !$ENV->user_cfg->{PAUSE}->{password} ) {
         say q[You need to specify PAUSE credentials.];
 
         return;
     }
 
     # check distance from the last release
-    if ( !$self->dist->id->{release_distance} ) {
+    if ( !$self->{dist}->id->{release_distance} ) {
         return if P->term->prompt( q[No changes since last release. Continue?], [qw[yes no]], enter => 1 ) eq 'no';
     }
 
     # check parent docker repo tag
-    if ( $self->dist->docker ) {
+    if ( $self->{dist}->docker ) {
         if ( !$ENV->user_cfg->{DOCKERHUB}->{username} || !$ENV->user_cfg->{DOCKERHUB}->{password} ) {
             say q[You need to specify DockerHub credentials.];
 
             return;
         }
 
-        say qq[Docker base image is "@{[$self->dist->docker->{from}]}".];
+        say qq[Docker base image is "@{[$self->{dist}->docker->{from}]}".];
 
-        if ( !$self->dist->is_pcore && $self->dist->docker->{from_tag} !~ /\Av\d+[.]\d+[.]\d+\z/sm ) {
+        if ( !$self->{dist}->is_pcore && $self->{dist}->docker->{from_tag} !~ /\Av\d+[.]\d+[.]\d+\z/sm ) {
             say q[Docker base image tag must be set to "vx.x.x". Use "pcore docker --from <TAG>" to set needed tag.];
 
             return;
@@ -188,9 +188,9 @@ sub _can_release ($self) {
 sub _compose_new_version ($self) {
 
     # show current and new versions, take confirmation
-    my $cur_ver = $self->dist->id->{release};
+    my $cur_ver = $self->{dist}->id->{release};
 
-    if ( $cur_ver eq 'v0.0.0' && $self->bugfix ) {
+    if ( $cur_ver eq 'v0.0.0' && $self->{bugfix} ) {
         say 'Bugfix is impossible on first release';
 
         return;
@@ -199,16 +199,16 @@ sub _compose_new_version ($self) {
     my ( $major, $minor, $bugfix ) = $cur_ver =~ /v(\d+)[.](\d+)[.](\d+)/sm;
 
     # increment version
-    if ( $self->major ) {
+    if ( $self->{major} ) {
         $major++;
         $minor  = 0;
         $bugfix = 0;
     }
-    elsif ( $self->minor ) {
+    elsif ( $self->{minor} ) {
         $minor++;
         $bugfix = 0;
     }
-    elsif ( $self->bugfix ) {
+    elsif ( $self->{bugfix} ) {
         $bugfix++;
     }
 
@@ -220,7 +220,7 @@ sub _compose_new_version ($self) {
         return;
     }
 
-    if ( $new_ver ~~ $self->dist->releases ) {
+    if ( $new_ver ~~ $self->{dist}->releases ) {
         say qq[Version $new_ver is already released];
 
         return;
@@ -232,7 +232,7 @@ sub _compose_new_version ($self) {
 sub _upload_to_cpan ($self) {
     print 'Creating .tgz ... ';
 
-    my $tgz = $self->dist->build->tgz;
+    my $tgz = $self->{dist}->build->tgz;
 
     say 'done';
 
@@ -261,9 +261,9 @@ sub _upload_to_cpan ($self) {
 }
 
 sub _create_changes ( $self, $ver, $issues ) {
-    state $init = !!require CPAN::Changes;
+    require CPAN::Changes;
 
-    my $changes_path = $self->dist->root . 'CHANGES';
+    my $changes_path = "$self->{dist}->{root}/CHANGES";
 
     my $changes = -f $changes_path ? CPAN::Changes->load($changes_path) : CPAN::Changes->new;
 
@@ -291,7 +291,7 @@ sub _create_changes ( $self, $ver, $issues ) {
     # get changesets since latest release
     my $tag = $ver eq 'v0.1.0' ? undef : 'latest';
 
-    my $changesets = $self->dist->scm->scm_get_changesets($tag);
+    my $changesets = $self->{dist}->scm->scm_get_changesets($tag);
 
     my $summary_idx;
 
@@ -311,7 +311,7 @@ TXT
         }
     }
 
-    my $tempfile = P->file->temppath;
+    my $tempfile = P->file1->tempfile;
 
     P->file->write_text( $tempfile, $log );
 
@@ -344,9 +344,6 @@ TXT
 ## |======+======================+================================================================================================================|
 ## |    3 | 14                   | Subroutines::ProhibitExcessComplexity - Subroutine "run" with high complexity score (26)                       |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 42, 62, 117, 122,    | ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    |
-## |      | 127, 132             |                                                                                                                |
-## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    1 | 278                  | BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
