@@ -36,7 +36,7 @@ sub CLI_RUN ( $self, $opt, $arg, $rest ) {
 
             $files->write_to( $dist->root );
 
-            say q[PAR profile was created. You should edit "par.ini" manually.];
+            say q[PAR profile was created. You should edit "par.yaml" manually.];
         }
 
         return;
